
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

module TaggableController
  extend ActiveSupport::Concern

  included do
    before_action :authenticate_user!, only: [:tagging, :untagging]
    before_action :set_owner, only: [:tagging, :untagging]
  end

  # POST /v1/learning_objects/1/tagging
  # POST /v1/learning_objects/1/tagging.json
  def tagging
    @owner.tag(taggable, with: [tag_params[:name]])
    render json: taggable.tags, status: :created
  end

  # DELETE /v1/learning_objects/1/untagging
  # DELETE /v1/learning_objects/1/untagging.json
  def untagging
    @owner.untag(taggable, with: [tag_params[:name]])
    render json: taggable.tags, status: :ok
  end

  protected

  def taggable
    raise NotImplementedError
  end

  def tag_params
    params.require(:tags).permit(:name, :owner_id, :owner_type)
  end

  def set_owner
    if current_user.is_admin?
      @owner = tag_params[:owner_type].constantize.find(tag_params[:owner_id])
    else
      if tag_params[:owner_type] == 'Institution'
        if Institution.find(tag_params[:owner_id]).users.include? current_user
          @owner = Institution.find(tag_params[:owner_id])
        end
      else
        @owner = current_user
      end
    end
  end

end
