
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class V1::LanguagesController < ApplicationController
  include ::Paginator

  before_action :authenticate_user!, except: [:index, :show]
  before_action :set_language, only: [:show, :update, :destroy]
  before_action :authorize!, only: [:update, :destroy]

  # GET /languages
  # GET /languages.json
  def index
    languages = paginate Language
    render json: languages
  end

  # GET /learning_objects/1
  # GET /learning_objects/1.json
  def show
    render json: @language
  end

  # POST /languages
  # POST /languages.json
  def create
    @language = Language.new(language_params)
    authorize @language

    if @language.save
      render json: @language, status: :created
    else
      render json: @language.errors, status: :unprocessable_entity
    end
  end

  # PATCH/PUT /languages/1
  # PATCH/PUT /languages/1.json
  def update
    if @language.update(language_params)
      render json: @language, status: :ok
    else
      render json: @language.errors, status: :unprocessable_entity
    end
  end

  # DELETE /languages/1
  # DELETE /languages/1.json
  def destroy
    @language.destroy
    response = { 'status': 'deleted' }
    render status: :ok, json: response
  end

  private

  # Use callbacks to share common setup or constraints between actions.
  def set_language
    @language = Language.where(id: params[:id]).first

    render status: :not_found if @language.blank?

    @language
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def language_params
    params.require(:language).permit(:name, :code)
  end

  def authorize!
    authorize @language
  end

end
