#
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.


class V1::LearningObjects::UploadsController < ApplicationController
  before_action :set_learning_object
  before_action :authorize!

  # POST /learning_objects/:learning_object_id/upload
  def create
    return render status: :bad_request unless valid_file?
    publisher = LearningObjectPublisher.new(DspaceService.create_client)
    path = saved_file
    attachment = @learning_object.attachments.create(name: File.basename(path), retrieve_link: path, bundle_name: "TEMP")
    publisher.upload @learning_object, path, attachment

    render status: :ok
  end

  private

  # Use callbacks to share common setup or constraints between actions.
  def set_learning_object
    @learning_object = LearningObject.where(id: params[:id]).first

    render status: :not_found if @learning_object.blank?

    @learning_object
  end

  def authorize!
    authorize(@learning_object || LearningObject.new, :update?)
  end

  def valid_file?
    upload_params[:file].is_a? ActionDispatch::Http::UploadedFile
  end

  def saved_file
    dir = File.join('public', 'uploads', @learning_object.id.to_s)
    FileUtils.mkpath(dir)

    path = File.join(dir, upload_params[:file].original_filename)
    FileUtils.mv(upload_params[:file].tempfile.path, path, force: true)
    FileUtils.chown_R 'portalmec', 'portalmec', path
    FileUtils.chmod 0644, path
    path
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def upload_params
    params.permit(:id, :file)
  end
end
