
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

# == Schema Information
#
# Table name: curator_assignments

# t.integer  "submission_id"
# t.integer  "user_id"
# t.integer  "status",        default: 0
# t.datetime "created_at",                null: false
# t.datetime "updated_at",                null: false


class CuratorAssignment < ApplicationRecord
  include Trackable

  enum status: [:assigned, :answered, :ignored]

  belongs_to :submission
  belongs_to :user

  validates :submission, :user, presence: true

  after_update :update_activities

  def update_activities
    if status_changed? && self.ignored?
      PublicActivity::Activity.where(trackable: self).update(parameters: { status: status })
    end
  end

  def activity_privacy
    'private'
  end

  def activity_recipient
    submission.learning_object
  end
end
