
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

# == Schema Information
#
# Table name: rates
#
#  id         :integer          not null, primary key
#  approves   :boolean
#  user_id    :integer
#  review_id  :integer
#  created_at :datetime         not null
#  updated_at :datetime         not null

class Rate < ApplicationRecord
  # *current_user* rate a review *review*
  include Trackable

  belongs_to :user
  belongs_to :review

  validates_presence_of :user, :review
  validates_inclusion_of :approves, in: [true, false]
  validates_uniqueness_of :user, scope: :review
  validate :cannot_rate_your_own, on: :create

  def recipient
    review
  end

  private

  def cannot_rate_your_own
    errors.add(:user_id, 'cannot rate your own review') if review.user == user
  end
end
