
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

# == Schema Information
#
# Table name: requirements

# t.belongs_to  "action"
# t.belongs_to  "achievement"
# t.string      "description"
# t.integer     "goal"
# t.boolean     "repeatable"

# t.datetime    "created_at"
# t.datetime    "updated_at"

class Requirement < ApplicationRecord
  belongs_to  :action
  has_many    :progresses
  has_many    :users, through: :progresses
  has_and_belongs_to_many :achievements

  accepts_nested_attributes_for :progresses, allow_destroy: true

  validates_presence_of :goal, :description, :action

  def add_achievements(ids=[])
    errors = []
    ids.each do |achievement_id|
      if !achievement_ids.include?(achievement_id)
        achievement = Achievement.where(id: achievement_id).first
        if !achievement.blank?
          achievements << achievement
        else
          errors << {error_type:"inexistent", id: achievement_id}
        end
      else
        errors << {error_type:"repeated", id: achievement_id}
      end
    end

    return errors
  end

  def remove_achievements(ids=[])
    ids.each do |achievement_id|
      achievement = achievements.where(id: achievement_id).first
      if !achievement.blank?
        self.achievements.delete(achievement)
      end
    end
  end

  def update_achievements(ids)
    ids ||= []
    add_achievements(ids - achievement_ids)
    remove_achievements(achievement_ids - ids)
  end
end
