
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

# == Schema Information
#
# Table name: views
#
#  id            :integer          not null, primary key
#  viewable_id   :integer
#  viewable_type :string
#  user_id       :integer
#  created_at    :datetime         not null
#  updated_at    :datetime         not null
#  ip            :string
#

class View < ApplicationRecord
  # *current_user* views *viewable*
  include Trackable

  belongs_to :viewable, polymorphic: true, counter_cache: true
  belongs_to :user, optional: true

  validates_presence_of :viewable, :ip

  before_create :current_time_greater_than_last
  after_create :create_action

  def recipient
    viewable
  end

  private

  def current_time_greater_than_last
    last_view = viewable.views.where(user: user, ip: ip).order('created_at DESC').limit(1).first

    unless last_view.blank?
      return false if Time.current < (last_view.created_at + 1.day)
    end

    true
  end

  def create_action
    if !user.nil?
      if viewable_type == "LearningObject"
        user.complete_action(Action.find_by_name("Visualizar um Recurso"))
        viewable.subjects.each do |subject|
          user.complete_action(Action.find_by_name("Visualizar um Recurso de #{subject.name}"))
        end
      end
      user.complete_action(Action.find_by_name("Visualizar uma Coleção")) if viewable_type == "Collection"
    end
  end
end
