
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'rainbow'

namespace :import do
  desc "import tags"

  task :tag, [:log] => [:environment] do |t, args|
    desc "Create Tag relations based on its metadata"
    include Log::Logging

    args.with_defaults(:log => STDOUT)

    Log::Logging.logger = Log::DatabaseLogger.new(args.log)
    logger.level = Log::DatabaseLogger::CREATE

    importer = TagsImporter.new

    # Quantity of items fetched on each iteration
    limit = 500
    # Start point from where items will be fetched
    offset = 0

    loop do
      logger.info " --> Creating Tag relations from #{offset} to #{offset + limit}"

      begin
        # Get learning_objects (from offset to offset+limit)
        learning_objects = LearningObject.limit(limit).offset(offset)

      rescue => e
        logger.warn 'Database error, going to sleep'
        logger.error e
        # Sleeps for a while to wait database's recovery
        sleep(10.seconds)
        # Goes to next iteration to retry
        next
      else
        # Terminate loop if there are no more learning_objects to import
        break if learning_objects.empty?

        importer.items = learning_objects
        importer.import

      end
      offset += limit
    end
    logger.close
  end

  private

  def get_items_from_dspace(limit, offset, expand=[])
    client = DspaceService.create_client
    client.items.all(
        expand: expand.join(','),
        limit: limit, offset: offset
    )
  end

end
