
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'acceptance_helpers'

resource 'Mime Types' do

  explanation "Mime Types are the types/extentions which an Object Type can have."

  before { 12.times { create(:mime_type) } }

  let(:mime_types) { MimeType.all }

  get '/v1/mime_types' do

    example_request 'Getting all mime_types' do
      expect(status).to eq(200)
    end
  end

  get '/v1/mime_types/:id' do

    let(:id) { mime_types.first.id }

    example_request 'Getting a mime_type' do
      expect(status).to eq(200)
    end
  end


  post '/v1/mime_types' do
    include_context "authenticate_user_admin"

    parameter :extension, 'The name of the mime_type', scope: :mime_type
    parameter :mime_type, 'The mime_type', scope: :mime_type

    let(:id) { mime_types.first.id }
    let(:extension) { Faker::File.extension }
    let(:mime_type) { Faker::File.mime_type }
    let(:raw_post) { params.to_json }

    example_request 'Create mime_types' do
      expect(status).to eq(201)
    end
  end

  put '/v1/mime_types/:id' do
    include_context "authenticate_user_admin"

    parameter :extension, 'The name of the mime_type', scope: :mime_type
    parameter :mime_type, 'The mime_type', scope: :mime_type

    let(:id) { mime_types.first.id }
    let(:extension) { Faker::File.extension }
    let(:mime_type) {  Faker::File.mime_type }
    let(:raw_post) { params.to_json }

    example_request 'Updating mime_types' do
      expect(status).to eq(200)
    end
  end

  delete '/v1/mime_types/:id' do
    include_context "authenticate_user_admin"

    let(:id) { mime_types.first.id }

    example_request 'Destroy a mime_type' do
      expect(status).to eq(200)
    end
  end

end
