
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'acceptance_helpers'
require 'shared/contexts'

resource 'Requirement' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  explanation "Achievements have requirements that users must complete to unlock them."

  before { 12.times { create(:requirement) }
    2.times { create(:achievement) } 
    1.times { create(:action) } 
  }

  let(:requirements) { Requirement.all }
  let(:all_achievements) { Achievement.all }
  let(:action) { Action.first }

  get '/v1/requirements' do
    parameter :limit, 'Limit of requirements'
    parameter :offset, 'Offset of requirements'

    let(:limit) { 12 }
    let(:offset) { 0 }

    example_request 'Get a list of requirements' do
      expect(JSON.parse(response_body).map { |o| o['id'] }.sort).to eq(requirements.limit(limit).offset(offset).pluck(:id).sort)
      expect(status).to eq(200)
    end
  end

  get '/v1/requirements/:id' do
    let(:id) { requirements.first.id }

    example 'Get a requirement' do
      do_request
      expect(path).to eq("/v1/requirements/#{id}") # `:id` is replaced with the value of `id`
      expect(response_body).to eq(Helper.serialize(requirements.find(id)))
      expect(status).to eq(200)
    end
  end

  post '/v1/requirements' do
    include_context "authenticate_user_editor"

    parameter :description, 'The description of the requirement', scope: :requirement
    parameter :goal, 'Amount of actions neccessary to fulfill the requirement', scope: :requirement
    parameter :repeatable, 'Whether the achievement can be repeated or not', scope: :requirement
    parameter :action_id, 'The id of the action needed for the requirement', scope: :requirement
    parameter :achievements, 'Array with achievements ids', scope: :requirement

    let(:description) { Faker::Lorem.paragraph}
    let(:goal) { rand(0..100) }
    let(:repeatable) { true }
    let(:action_id) { action.id }
    let(:achievements) { [all_achievements.first.id] }
    let(:raw_post) { params.to_json }

    example 'Creating an requirement' do
      do_request
      expect(status).to eq(201)
    end
  end

  put '/v1/requirements/:id' do
    include_context "authenticate_user_editor"

    parameter :description, 'The description of the requirement', scope: :requirement
    parameter :goal, 'Amount of actions neccessary to fulfill the requirement', scope: :requirement
    parameter :repeatable, 'Whether the achievement can be repeated or not', scope: :requirement
    parameter :action_id, 'The id of the action needed for the requirement', scope: :requirement
    parameter :achievements, 'Array with achievements ids', scope: :requirement

    let(:id) { @requirement.id }
    let(:description) { Faker::Lorem.paragraph }
    let(:raw_post) { params.to_json }

    before do
      @requirement = create(:requirement)
    end

    example 'Updating a requirement' do
      do_request
      expect(status).to eq(200)
    end
  end

  delete '/v1/requirements/:id' do
    include_context "authenticate_user_editor"

    let(:id) { @requirement.id }

    before do
      @requirement = create(:requirement)
    end

    example 'Destroying a requirement' do
      do_request
      expect(status).to eq(200)
    end

  end

end
