
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

require 'acceptance_helpers'
require 'shared/contexts'

resource 'Subjects' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  explanation "Subjects to digital resources, like Artes, Biologia."

  before { 12.times { create(:subject); create(:learning_object) } }

  let(:subject) { Subject.all }
  let(:learning_objects) { LearningObject.all }

  get '/v1/subjects' do

    example_request 'Get a list of subjects' do
      # active model serializer may render model associations in different order for collections (array of items), so we're verifing only returned ids
      expect(status).to eq(200)
    end
  end

  post 'v1/:type/:id/subjects' do
    include_context "authenticate_user"

    parameter :id, "The id of the object"
    parameter :type, "Represents the type of the object [LearningObject, Collection]"
    parameter :subjects, "The array of subjects"

    let(:type) {'learning_objects'}
    let(:id) {@learning_object.id}
    let(:subjects) { [subject.first.id ] }
    let(:raw_post) {params.to_json}

    before do
      @learning_object = create(:learning_object, publisher: @user)
    end

    example 'Adding subjects' do
      do_request
      expect(status).to eq(201)
    end
  end

  delete 'v1/:type/:id/subjects' do
    include_context "authenticate_user_admin"

    parameter :id, "The id of the object"
    parameter :type, "Represents the type of the object [LearningObject, Collection]"
    parameter :subjects, "The array of subjects"

    let(:type) {'learning_objects'}
    let(:id) {@learning_object.id}
    let(:subjects) { [subject.first.id ] }
    let(:raw_post) {params.to_json}

    before do
      @learning_object = create(:learning_object, publisher: @user)
      relation = SubjectRelation.where(subjectable_id: @learning_object.id, subjectable_type: "LearningObject", subject_id: subject.first.id)
      create(:subject_relation, subjectable: @learning_object, subject: subject.first) if relation.blank?
    end

    example 'Removing subjects' do
      do_request
      expect(status).to eq(200)
    end
  end
end
