
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.require 'acceptance_helpers'

require 'acceptance_helpers'
require 'shared/contexts'

resource 'Unlocked Achievements' do
  header 'Accept', 'application/json'
  header 'Content-Type', 'application/json'

  explanation "Unlocked Achievements from a User"

  before { 12.times { create(:unlocked_achievement) } }

  let(:unlocked_achievements) { UnlockedAchievement.all }

  get '/v1/unlocked_achievements' do   #index
    include_context "authenticate_user"

    before { 12.times { create(:unlocked_achievement, user: @user) }}

    parameter :limit, 'Limit of unlocked achievements'
    parameter :offset, 'Offset of unlocked achievements'

    let(:limit) { 12 }
    let(:offset) { 0 }

    example_request 'Get a list of unlocked achievements from a user' do
      expect( JSON.parse(response_body).map { |o| o['id'] }.sort ).to eq( @user.unlocked_achievements.limit(limit).offset(offset).pluck(:id).sort )
      expect(status).to eq(200)
    end
  end

  get '/v1/unlocked_achievements/:id' do

    let(:id) { unlocked_achievements.first.id }      

    example 'Get a specific unlocked achievement' do
      do_request
      expect(path).to eq("/v1/unlocked_achievements/#{id}")
      expect(response_body).to eq(Helper.serialize(UnlockedAchievement.find(id)))
      expect(status).to eq(200)
    end
  end
end